==> R14.1.0-core.tar: tdepim-trinity-14.1.0/kaddressbook/addresseeeditorextension.cpp <==
/*
    This file is part of KAddressBook.
    Copyright (c) 2005 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of TQt, and distribute the resulting executable,
    without including the source code for TQt in the source distribution.
*/

#include <tqlayout.h>
#include <tqtimer.h>

#include <tdelocale.h>

#include "kabprefs.h"

#include "addresseeeditorwidget.h"
#include "simpleaddresseeeditor.h"

#include "addresseeeditorextension.h"

AddresseeEditorExtension::AddresseeEditorExtension( KAB::Core *core, TQWidget *parent, const char *name )
  : KAB::ExtensionWidget( core, parent, name )
{
  TQVBoxLayout *layout = new TQVBoxLayout( this );

  if ( KABPrefs::instance()->editorType() == KABPrefs::SimpleEditor )
    mAddresseeEditor = new SimpleAddresseeEditor( this );
  else
    mAddresseeEditor = new AddresseeEditorWidget( this );

  layout->addWidget( mAddresseeEditor );
}

AddresseeEditorExtension::~AddresseeEditorExtension()
{
}

void AddresseeEditorExtension::contactsSelectionChanged()
{
  const TDEABC::Addressee::List selectedAddressees = selectedContacts();
  TDEABC::Addressee::List modifiedAddress;
  if ( mAddresseeEditor->dirty() ) {
    mAddresseeEditor->save();
    addressees.append( mAddresseeEditor->addressee() );
    modifiedAddress = addressees;
    TQTimer::singleShot(0, this, TQT_SLOT(emitModifiedAddresses()));
  }

  mAddresseeEditor->setAddressee( selectedAddressees[ 0 ] );
}

void AddresseeEditorExtension::emitModifiedAddresses()
{
  emit modified( addressees );
}

TQString AddresseeEditorExtension::title() const
{
  return i18n( "Contact Editor" );
}

TQString AddresseeEditorExtension::identifier() const
{
  return "contact_editor";
}

#include "addresseeeditorextension.moc"

==> R14.1.4-core.tar: tdepim-trinity-14.1.4/kaddressbook/addresseeeditorextension.cpp <==
/*
    This file is part of KAddressBook.
    Copyright (c) 2005 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of TQt, and distribute the resulting executable,
    without including the source code for TQt in the source distribution.
*/

#include <tqlayout.h>
#include <tqtimer.h>

#include <tdelocale.h>

#include "kabprefs.h"

#include "addresseeeditorwidget.h"
#include "simpleaddresseeeditor.h"

#include "addresseeeditorextension.h"

AddresseeEditorExtension::AddresseeEditorExtension( KAB::Core *core, TQWidget *parent, const char *name )
  : KAB::ExtensionWidget( core, parent, name )
{
  TQVBoxLayout *layout = new TQVBoxLayout( this );

  if ( KABPrefs::instance()->editorType() == KABPrefs::SimpleEditor )
    mAddresseeEditor = new SimpleAddresseeEditor( this );
  else
    mAddresseeEditor = new AddresseeEditorWidget( this );

  layout->addWidget( mAddresseeEditor );
}

AddresseeEditorExtension::~AddresseeEditorExtension()
{
}

void AddresseeEditorExtension::contactsSelectionChanged()
{
  const TDEABC::Addressee::List selectedAddressees = selectedContacts();
  TDEABC::Addressee::List modifiedAddress;
  if ( mAddresseeEditor->dirty() ) {
    mAddresseeEditor->save();
    addressees.append( mAddresseeEditor->addressee() );
    modifiedAddress = addressees;
    TQTimer::singleShot(0, this, TQ_SLOT(emitModifiedAddresses()));
  }

  mAddresseeEditor->setAddressee( selectedAddressees[ 0 ] );
}

void AddresseeEditorExtension::emitModifiedAddresses()
{
  emit modified( addressees );
}

TQString AddresseeEditorExtension::title() const
{
  return i18n( "Contact Editor" );
}

TQString AddresseeEditorExtension::identifier() const
{
  return "contact_editor";
}

#include "addresseeeditorextension.moc"
